==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassListFluent.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface BypassListFluent<A extends BypassListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Bypass item);
    public A setToItems(int index,Bypass item);
    public A addToItems(Bypass... items);
    public A addAllToItems(Collection<Bypass> items);
    public A removeFromItems(Bypass... items);
    public A removeAllFromItems(Collection<Bypass> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Bypass> getItems();
    public List<Bypass> buildItems();
    public Bypass buildItem(int index);
    public Bypass buildFirstItem();
    public Bypass buildLastItem();
    public Bypass buildMatchingItem(Predicate<BypassBuilder> predicate);
    public A withItems(List<Bypass> items);
    public A withItems(Bypass... items);
    public Boolean hasItems();
    public BypassListFluent.ItemsNested<A> addNewItem();
    public BypassListFluent.ItemsNested<A> addNewItemLike(Bypass item);
    public BypassListFluent.ItemsNested<A> setNewItemLike(int index,Bypass item);
    public BypassListFluent.ItemsNested<A> editItem(int index);
    public BypassListFluent.ItemsNested<A> editFirstItem();
    public BypassListFluent.ItemsNested<A> editLastItem();
    public BypassListFluent.ItemsNested<A> editMatchingItem(Predicate<BypassBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,BypassFluent<BypassListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/bypass/BypassListFluent.java <==
package me.snowdrop.istio.mixer.adapter.bypass;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface BypassListFluent<A extends BypassListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Bypass item);
    public A setToItems(int index,Bypass item);
    public A addToItems(Bypass... items);
    public A addAllToItems(Collection<Bypass> items);
    public A removeFromItems(Bypass... items);
    public A removeAllFromItems(Collection<Bypass> items);
    public A removeMatchingFromItems(Predicate<BypassBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Bypass> getItems();
    public List<Bypass> buildItems();
    public Bypass buildItem(int index);
    public Bypass buildFirstItem();
    public Bypass buildLastItem();
    public Bypass buildMatchingItem(Predicate<BypassBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<BypassBuilder> predicate);
    public A withItems(List<Bypass> items);
    public A withItems(Bypass... items);
    public Boolean hasItems();
    public BypassListFluent.ItemsNested<A> addNewItem();
    public BypassListFluent.ItemsNested<A> addNewItemLike(Bypass item);
    public BypassListFluent.ItemsNested<A> setNewItemLike(int index,Bypass item);
    public BypassListFluent.ItemsNested<A> editItem(int index);
    public BypassListFluent.ItemsNested<A> editFirstItem();
    public BypassListFluent.ItemsNested<A> editLastItem();
    public BypassListFluent.ItemsNested<A> editMatchingItem(Predicate<BypassBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,BypassFluent<BypassListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
